%% ==========================================================================================================
%% Syn - A global process registry.
%%
%% Copyright (C) 2015, Roberto Ostinelli <roberto@ostinelli.net>.
%% All rights reserved.
%%
%% The MIT License (MIT)
%%
%% Copyright (c) 2015 Roberto Ostinelli
%%
%% Permission is hereby granted, free of charge, to any person obtaining a copy
%% of this software and associated documentation files (the "Software"), to deal
%% in the Software without restriction, including without limitation the rights
%% to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
%% copies of the Software, and to permit persons to whom the Software is
%% furnished to do so, subject to the following conditions:
%%
%% The above copyright notice and this permission notice shall be included in
%% all copies or substantial portions of the Software.
%%
%% THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
%% IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
%% FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
%% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
%% LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
%% OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
%% THE SOFTWARE.
%% ==========================================================================================================
-module(syn_test_suite_helper).

%% API
-export([start_slave/1, stop_slave/1]).
-export([clean_after_test/0, clean_after_test/1]).


%% ===================================================================
%% API
%% ===================================================================
start_slave(NodeShortName) ->
    EbinFilePath = filename:join([filename:dirname(code:lib_dir(syn, ebin)), "ebin"]),
    %% start slave
    {ok, NodeName} = ct_slave:start(NodeShortName, [
        {boot_timeout, 10},
        {monitor_master, true},
        {erl_flags, string:concat("-pa ", EbinFilePath)}
    ]),
    {ok, NodeName}.

stop_slave(NodeShortName) ->
    {ok, _} = ct_slave:stop(NodeShortName).

clean_after_test() ->
    %% delete table
    {atomic, ok} = mnesia:delete_table(syn_processes_table),
    %% stop mnesia
    mnesia:stop(),
    %% delete schema
    mnesia:delete_schema([node()]),
    %% stop syn
    syn:stop().

clean_after_test(NodeName) ->
    %% delete table
    {atomic, ok} = mnesia:delete_table(syn_processes_table),
    %% stop mnesia
    mnesia:stop(),
    rpc:call(NodeName, mnesia, stop, []),
    %% delete schema
    mnesia:delete_schema([node(), NodeName]),
    %% stop syn
    syn:stop(),
    rpc:call(NodeName, syn, stop, []).
